@@ -12,21 +12,6 @@ class Service:
     
         if config is not None:
             self.config = config
-    
-    def __del__(self):
-        if hasattr(self, 'repository'):
-            self.repository.close()
-
-    def all(self) -> 'list[Model]':
-        entities = self.repository.all(entity_type=self.entity_type)
-        return entities
-
-    def load(self, entity: Model) -> Model:
-        entity = self.repository.load(entity=entity)
-        return entity
-
-    def save(self, entity: Model) -> None:
-        self.repository.save(entity=entity)
 
     def wget(self, url: str, parameters: dict=None, method: Requests.Methods=Requests.Methods.GET, response_type: Requests.ResponseTypes=Requests.ResponseTypes.JSON) -> any:
         if method == Requests.Methods.GET:
